starcluster.commands.listbuckets

Package starcluster :: Package commands :: Module listbuckets |
[hide private]
[frames] | no frames]

# Source Code for Module starcluster.commands.listbuckets

     1  #!/usr/bin/env python
     2
     3  from base import CmdBase
     4
     5
     6 -class CmdListBuckets(CmdBase):
     7      """
     8      listbuckets
     9
    10      List all S3 buckets
    11      """
    12      names = ['listbuckets', 'lb']
    13
    14 -    def execute(self, args):
    15          self.s3.list_buckets()
    16